package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.GovernmentCloudDedicatedLineMapper;
import com.zyc.system.domain.GovernmentCloudDedicatedLine;
import com.zyc.system.service.IGovernmentCloudDedicatedLineService;

/**
 * 政务云专线Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class GovernmentCloudDedicatedLineServiceImpl implements IGovernmentCloudDedicatedLineService 
{
    @Autowired
    private GovernmentCloudDedicatedLineMapper governmentCloudDedicatedLineMapper;

    /**
     * 查询政务云专线
     * 
     * @param id 政务云专线主键
     * @return 政务云专线
     */
    @Override
    public GovernmentCloudDedicatedLine selectGovernmentCloudDedicatedLineById(Integer id)
    {
        return governmentCloudDedicatedLineMapper.selectGovernmentCloudDedicatedLineById(id);
    }

    /**
     * 查询政务云专线列表
     * 
     * @param governmentCloudDedicatedLine 政务云专线
     * @return 政务云专线
     */
    @Override
    public List<GovernmentCloudDedicatedLine> selectGovernmentCloudDedicatedLineList(GovernmentCloudDedicatedLine governmentCloudDedicatedLine)
    {
        return governmentCloudDedicatedLineMapper.selectGovernmentCloudDedicatedLineList(governmentCloudDedicatedLine);
    }

    /**
     * 新增政务云专线
     * 
     * @param governmentCloudDedicatedLine 政务云专线
     * @return 结果
     */
    @Override
    public int insertGovernmentCloudDedicatedLine(GovernmentCloudDedicatedLine governmentCloudDedicatedLine)
    {
        return governmentCloudDedicatedLineMapper.insertGovernmentCloudDedicatedLine(governmentCloudDedicatedLine);
    }

    /**
     * 修改政务云专线
     * 
     * @param governmentCloudDedicatedLine 政务云专线
     * @return 结果
     */
    @Override
    public int updateGovernmentCloudDedicatedLine(GovernmentCloudDedicatedLine governmentCloudDedicatedLine)
    {
        return governmentCloudDedicatedLineMapper.updateGovernmentCloudDedicatedLine(governmentCloudDedicatedLine);
    }

    /**
     * 批量删除政务云专线
     * 
     * @param ids 需要删除的政务云专线主键
     * @return 结果
     */
    @Override
    public int deleteGovernmentCloudDedicatedLineByIds(Integer[] ids)
    {
        return governmentCloudDedicatedLineMapper.deleteGovernmentCloudDedicatedLineByIds(ids);
    }

    /**
     * 删除政务云专线信息
     * 
     * @param id 政务云专线主键
     * @return 结果
     */
    @Override
    public int deleteGovernmentCloudDedicatedLineById(Integer id)
    {
        return governmentCloudDedicatedLineMapper.deleteGovernmentCloudDedicatedLineById(id);
    }
}
